==> 1.13.0.tar.gz: lib/src/videos/widgets/ModernFormViewVideos/ModernFormViewVideosModel.dart <==
part of modern_form_videos;

class ModernFormViewVideosModel {
  String? url;
  String? path;
  bool? shareArquiveEnabled;
  final void Function()? onShareVideoArquiveCallback;
  final void Function()? onShareVideoUrlCallback;
  final void Function()? onDeleteVideoFromDevice;
  final void Function()? onDownloadVideoCallback;
  final void Function()? onOpenVideoCallback;

  ModernFormViewVideosModel({
    this.url,
    this.path,
    this.shareArquiveEnabled,
    this.onShareVideoArquiveCallback,
    this.onShareVideoUrlCallback,
    this.onDeleteVideoFromDevice,
    this.onDownloadVideoCallback,
    this.onOpenVideoCallback,
  });

  ModernFormViewVideosModel copyWith({
    String? url,
    String? path,
    bool? shareArquiveEnabled,
    void Function()? onShareVideoArquiveCallback,
    void Function()? onShareVideoUrlCallback,
    void Function()? onDeleteVideoFromDevice,
    void Function()? onDownloadVideoCallback,
    void Function()? onOpenVideoCallback,
  }) {
    return ModernFormViewVideosModel(
      url: url ?? this.url,
      path: path ?? this.path,
      shareArquiveEnabled: shareArquiveEnabled ?? this.shareArquiveEnabled,
      onShareVideoArquiveCallback:
          onShareVideoArquiveCallback ?? this.onShareVideoArquiveCallback,
      onShareVideoUrlCallback:
          onShareVideoUrlCallback ?? this.onShareVideoUrlCallback,
      onDeleteVideoFromDevice:
          onDeleteVideoFromDevice ?? this.onDeleteVideoFromDevice,
      onDownloadVideoCallback:
          onDownloadVideoCallback ?? this.onDownloadVideoCallback,
      onOpenVideoCallback: onOpenVideoCallback ?? this.onOpenVideoCallback,
    );
  }

  @override
  String toString() =>
      'ModernFormViewVideosModel(url: $url, path: $path, shareArquiveEnabled: $shareArquiveEnabled)';

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is ModernFormViewVideosModel &&
        other.url == url &&
        other.path == path &&
        other.onShareVideoArquiveCallback == onShareVideoArquiveCallback &&
        other.onShareVideoUrlCallback == onShareVideoUrlCallback &&
        other.onDeleteVideoFromDevice == onDeleteVideoFromDevice &&
        other.onDownloadVideoCallback == onDownloadVideoCallback &&
        other.onOpenVideoCallback == onOpenVideoCallback &&
        other.shareArquiveEnabled == shareArquiveEnabled;
  }

  @override
  int get hashCode =>
      url.hashCode ^
      path.hashCode ^
      shareArquiveEnabled.hashCode ^
      onShareVideoArquiveCallback.hashCode ^
      onShareVideoUrlCallback.hashCode ^
      onDeleteVideoFromDevice.hashCode ^
      onDownloadVideoCallback.hashCode ^
      onOpenVideoCallback.hashCode;
}

==> 1.17.1.tar.gz: lib/src/videos/widgets/ModernFormViewVideos/ModernFormViewVideosModel.dart <==
part of modern_form_videos;

class ModernFormViewVideosModel {
  String? url;
  String? path;
  bool? shareArquiveEnabled;
  void Function()? onShareVideoArquiveCallback;
  void Function()? onShareVideoUrlCallback;
  void Function()? onDeleteVideoFromDevice;
  void Function()? onDownloadVideoCallback;
  void Function()? onOpenVideoCallback;

  ModernFormViewVideosModel({
    this.url,
    this.path,
    this.shareArquiveEnabled,
    this.onShareVideoArquiveCallback,
    this.onShareVideoUrlCallback,
    this.onDeleteVideoFromDevice,
    this.onDownloadVideoCallback,
    this.onOpenVideoCallback,
  });

  ModernFormViewVideosModel copyWith({
    String? url,
    String? path,
    bool? shareArquiveEnabled,
    void Function()? onShareVideoArquiveCallback,
    void Function()? onShareVideoUrlCallback,
    void Function()? onDeleteVideoFromDevice,
    void Function()? onDownloadVideoCallback,
    void Function()? onOpenVideoCallback,
  }) {
    return ModernFormViewVideosModel(
      url: url ?? this.url,
      path: path ?? this.path,
      shareArquiveEnabled: shareArquiveEnabled ?? this.shareArquiveEnabled,
      onShareVideoArquiveCallback:
          onShareVideoArquiveCallback ?? this.onShareVideoArquiveCallback,
      onShareVideoUrlCallback:
          onShareVideoUrlCallback ?? this.onShareVideoUrlCallback,
      onDeleteVideoFromDevice:
          onDeleteVideoFromDevice ?? this.onDeleteVideoFromDevice,
      onDownloadVideoCallback:
          onDownloadVideoCallback ?? this.onDownloadVideoCallback,
      onOpenVideoCallback: onOpenVideoCallback ?? this.onOpenVideoCallback,
    );
  }

  @override
  String toString() =>
      'ModernFormViewVideosModel(url: $url, path: $path, shareArquiveEnabled: $shareArquiveEnabled)';

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) return true;

    return other is ModernFormViewVideosModel &&
        other.url == url &&
        other.path == path &&
        other.onShareVideoArquiveCallback == onShareVideoArquiveCallback &&
        other.onShareVideoUrlCallback == onShareVideoUrlCallback &&
        other.onDeleteVideoFromDevice == onDeleteVideoFromDevice &&
        other.onDownloadVideoCallback == onDownloadVideoCallback &&
        other.onOpenVideoCallback == onOpenVideoCallback &&
        other.shareArquiveEnabled == shareArquiveEnabled;
  }

  @override
  int get hashCode =>
      url.hashCode ^
      path.hashCode ^
      shareArquiveEnabled.hashCode ^
      onShareVideoArquiveCallback.hashCode ^
      onShareVideoUrlCallback.hashCode ^
      onDeleteVideoFromDevice.hashCode ^
      onDownloadVideoCallback.hashCode ^
      onOpenVideoCallback.hashCode;
}
